@@ -21,6 +21,7 @@ import logging
 from datetime import datetime as dt
 from pathlib import Path
 
+from txt2ebook.helpers import lower_underscore
 from txt2ebook.models import Book, Chapter, Volume
 
 logger = logging.getLogger(__name__)
@@ -75,10 +76,14 @@ class TxtWriter:
                 self._new_file()
 
     def _export_multiple_files(self) -> None:
+        logger.info("Split multiple files")
+
         txt_filename = Path(self.filename)
         export_filename = Path(
             txt_filename.resolve().parent.joinpath(
-                f"00_{txt_filename.stem}_" + self._("metadata") + ".txt"
+                lower_underscore(
+                    f"00_{txt_filename.stem}_" + self._("metadata") + ".txt"
+                )
             )
         )
         logger.info("Creating %s", export_filename)
@@ -89,7 +94,9 @@ class TxtWriter:
         if self.with_toc:
             export_filename = Path(
                 txt_filename.resolve().parent.joinpath(
-                    f"01_{txt_filename.stem}_" + self._("toc") + ".txt"
+                    lower_underscore(
+                        f"01_{txt_filename.stem}_" + self._("toc") + ".txt"
+                    )
                 )
             )
             logger.info("Creating %s", export_filename)
@@ -105,14 +112,16 @@ class TxtWriter:
             if isinstance(section, Volume):
                 for chapter in section.chapters:
                     chapter_seq = str(ct_seq).rjust(2, "0")
-                    filename = (
-                        f"{section_seq}"
-                        f"_{chapter_seq}"
-                        f"_{txt_filename.stem}"
-                        f"_{section.title}"
-                        f"_{chapter.title}"
-                        ".txt"
-                    ).replace(" ", "_")
+                    filename = lower_underscore(
+                        (
+                            f"{section_seq}"
+                            f"_{chapter_seq}"
+                            f"_{txt_filename.stem}"
+                            f"_{section.title}"
+                            f"_{chapter.title}"
+                            ".txt"
+                        )
+                    )
 
                     export_filename = Path(
                         txt_filename.resolve().parent.joinpath(filename)
@@ -124,12 +133,15 @@ class TxtWriter:
                         )
                     ct_seq = ct_seq + 1
             if isinstance(section, Chapter):
-                filename = (
-                    f"{section_seq}"
-                    f"_{txt_filename.stem}"
-                    f"_{section.title}"
-                    ".txt"
+                filename = lower_underscore(
+                    (
+                        f"{section_seq}"
+                        f"_{txt_filename.stem}"
+                        f"_{section.title}"
+                        ".txt"
+                    )
                 )
+
                 export_filename = Path(
                     txt_filename.resolve().parent.joinpath(filename)
                 )
@@ -145,7 +157,7 @@ class TxtWriter:
         ymd_hms = dt.now().strftime("%Y%m%d_%H%M%S")
         new_filename = Path(
             txt_filename.resolve().parent.joinpath(
-                txt_filename.stem + "_" + ymd_hms + ".txt"
+                lower_underscore(txt_filename.stem + "_" + ymd_hms + ".txt")
             )
         )
 
