@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022 Kian-Meng Ang
+# Copyright (C) 2021,2022,2023 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -20,13 +20,12 @@ from txt2ebook.languages.zh_cn import (
     DEFAULT_RE_CHAPTER,
     DEFAULT_RE_TITLE,
     DEFAULT_RE_VOLUME,
-    DEFAULT_RE_VOLUME_CHAPTER,
     FULLWIDTH_NUMS,
+    HALFWIDTH_NUMS,
     IDEOGRAPHIC_SPACE,
     NUMS_WORDS,
     RE_NUMS,
     SPACE,
-    STRUCTURE_NAMES,
 )
 
 __all__ = [
@@ -34,11 +33,10 @@ __all__ = [
     "DEFAULT_RE_CHAPTER",
     "DEFAULT_RE_TITLE",
     "DEFAULT_RE_VOLUME",
-    "DEFAULT_RE_VOLUME_CHAPTER",
     "FULLWIDTH_NUMS",
+    "HALFWIDTH_NUMS",
     "IDEOGRAPHIC_SPACE",
     "NUMS_WORDS",
     "RE_NUMS",
     "SPACE",
-    "STRUCTURE_NAMES",
 ]
