@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022 Kian-Meng Ang
+# Copyright (C) 2021,2022,2023 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -27,7 +27,19 @@ class Volume:
 
     title: str = field(default="")
     chapters: List[Chapter] = field(default_factory=list, repr=False)
-    raw_content: str = field(default="", repr=False)
+
+    def __repr__(self) -> str:
+        """Return the string representation of Volume for debugging purpose.
+
+        Returns:
+          str: Debugging string for logging
+        """
+        # pylint: disable=bad-option-value,consider-using-f-string
+        return "{}(title='{}', chapters='{}')".format(
+            self.__class__.__name__,
+            self.title,
+            len(self.chapters),
+        )
 
     def add_chapter(self, chapter: Chapter) -> None:
         """Append a chapter to the current volume."""
